/*
  Copyright (C) 2002-2023 CERN for the benefit of the ATLAS collaboration
*/

#ifndef GEOPIXELSIMPLESTAVESUPPORT_H
#define GEOPIXELSIMPLESTAVESUPPORT_H

#include "GeoPixelStaveSupport.h"
#include "GeoPrimitives/GeoPrimitives.h"
#include "GeoModelKernel/GeoDefinitions.h"

class GeoPixelSimpleStaveSupport : public GeoPixelStaveSupport {

public:  
  GeoPixelSimpleStaveSupport(InDetDD::PixelDetectorManager* ddmgr,
                             PixelGeometryManager* mgr,
			     GeoModelIO::ReadGeoModel* sqliteReader,
                             std::shared_ptr<std::map<std::string, GeoFullPhysVol*>> mapFPV,
                             std::shared_ptr<std::map<std::string, GeoAlignableTransform*>> mapAX);
  virtual ~GeoPixelSimpleStaveSupport() = default;
  virtual GeoVPhysVol* Build() override;
  virtual GeoVPhysVol* getPhysVol() override {return m_physVol;}
  virtual const GeoTrf::Transform3D & transform() const override {return m_transform;}
  virtual double thicknessP() const override {return m_thicknessP;}
  virtual double thicknessN() const override {return m_thicknessN;}
  virtual GeoSimplePolygonBrep* computeStaveEnvelopShape(double) override { return 0;}
  virtual GeoVPhysVol* getEndblockEnvelopShape(int) override { return 0;}
  virtual GeoTransform* getEndblockEnvelopShapeTrf(int) override {return 0;}
  virtual double getEndblockZpos() const override { return 0.; }
  virtual double getServiceZpos() const override { return 0; }
  virtual double getEndblockLength() const override { return 0.; }

  virtual void computeStaveEnvelopTransformAndSize(double ,double, double, double, double, double) override {};

  virtual int PixelNModule() const override {return 0;} 
  virtual int PixelNPlanarModule() const override {return 0;}
  virtual int PixelN3DModule() const override {return 0;}

private:
  PVLink m_physVol{};
  GeoTrf::Transform3D m_transform;
  double m_thicknessP = 0.0;
  double m_thicknessN = 0.0;
};

#endif


