/*
  Copyright (C) 2002-2021 CERN for the benefit of the ATLAS collaboration
*/

#ifndef PIXELRAWDATABYTESTREAMCNV_PIXELRAWDATAPROVIDERTOOL_H
#define PIXELRAWDATABYTESTREAMCNV_PIXELRAWDATAPROVIDERTOOL_H

#include "PixelRawDataByteStreamCnv/IPixelRawDataProviderTool.h"
#include "PixelRawDataByteStreamCnv/IPixelRodDecoder.h"
#include "AthenaBaseComps/AthAlgTool.h"
#include "AthenaKernel/SlotSpecificObj.h"
#include "StoreGate/WriteHandleKey.h"
#include "InDetRawData/InDetTimeCollection.h"

#include "GaudiKernel/EventContext.h"
#include "GaudiKernel/ToolHandle.h"

#include <atomic>

// the tool to decode a ROB frament
class PixelRawDataProviderTool : virtual public IPixelRawDataProviderTool, public AthAlgTool
{

 public:
   
  //! constructor
  PixelRawDataProviderTool( const std::string& type, const std::string& name,
			    const IInterface* parent ) ;

  //! initialize
  StatusCode initialize() override;

  //! this is the main decoding method
  StatusCode convert( std::vector<const OFFLINE_FRAGMENTS_NAMESPACE::ROBFragment*>& vecRobs,
		      IPixelRDO_Container* rdoIdc,
		      IDCInDetBSErrContainer& decodingErrors, const EventContext& ctx) const final;

  //! Size of IDCInDetBSErrContainer
  int SizeOfIDCInDetBSErrContainer() const final;

private: 
  
  ToolHandle<IPixelRodDecoder>  m_decoder
  {this, "Decoder", "PixelRodDecoder", "Tool for PixelRodDecoder"};


  SG::WriteHandleKey<InDetTimeCollection> m_LVL1CollectionKey{this, "LVL1CollectionName", "PixelLVL1ID"};
  SG::WriteHandleKey<InDetTimeCollection> m_BCIDCollectionKey{this, "BCIDCollectionName", "PixelBCID"};
  Gaudi::Property<bool> m_storeInDetTimeColls{this, "StoreInDetTimeCollections", true, "Store LVL1ID and BCID"};

  mutable std::atomic_int m_DecodeErrCount;
};

#endif
