/*
Copyright (C) 2002-2024 CERN for the benefit of the ATLAS collaboration
*/
#include <AthenaKernel/getMessageSvc.h>
#include <GaudiKernel/MsgStream.h>
#include <MuonTesterTree/ArrayBranch.h>
#include <MuonTesterTree/MuonTesterBranch.h>
#include <MuonTesterTree/MuonTesterTree.h>
#include <MuonTesterTree/ScalarBranch.h>
#include <MuonTesterTree/VectorBranch.h>
#include <MuonTesterTree/throwExcept.h>

#include <functional>

#define SET_BRANCHSTRING(theType, thestring) \
    template <> std::string ArrayBranch<theType>::tree_data_type() const { return thestring; }
namespace MuonVal {
SET_BRANCHSTRING(Char_t, "/B")
SET_BRANCHSTRING(std::string, "/C")
SET_BRANCHSTRING(UChar_t, "/b")
SET_BRANCHSTRING(Short_t, "/S")
SET_BRANCHSTRING(Int_t, "/I")
SET_BRANCHSTRING(Long64_t, "/L")
SET_BRANCHSTRING(long, "/I")
SET_BRANCHSTRING(unsigned long, "/i")
SET_BRANCHSTRING(UShort_t, "/s")
SET_BRANCHSTRING(UInt_t, "/i")
SET_BRANCHSTRING(ULong64_t, "/l")
SET_BRANCHSTRING(Float_t, "/F")
SET_BRANCHSTRING(Double_t, "/D")
SET_BRANCHSTRING(Bool_t, "/o")

MuonTesterBranch::MuonTesterBranch(MuonTesterTree& tree, const std::string& br_name) : 
    MuonTesterBranch(tree.tree(), br_name) {
    m_parent = &tree;
    m_parent->addBranch(this);
}
MuonTesterTree& MuonTesterBranch::parent() {
    if (!m_parent) {
        ATH_MSG_WARNING("The parent of  " << name() << " is null.");
    }
    return *m_parent;
}
MuonTesterBranch::~MuonTesterBranch() {
    if (m_parent) {
        m_parent->removeBranch(this);
    }
}
MuonTesterBranch::MuonTesterBranch(TTree* tree, const std::string& br_name) :
    AthMessaging{"MuonTesterBranch"}, m_tree(tree), m_name(br_name) {}
std::string MuonTesterBranch::name() const { return m_name; }
bool MuonTesterBranch::initialized() const { return m_init; }
TTree* MuonTesterBranch::tree() { return m_tree; }
const TTree* MuonTesterBranch::tree() const { return m_tree; }

std::string MuonTesterBranch::eraseWhiteSpaces(const std::string& In) {
    std::string out = In;
    out.erase(std::remove_if(out.begin(), out.end(), isspace), out.end());
    return out;
}
std::vector<MuonTesterBranch::DataDependency> MuonTesterBranch::data_dependencies() { return m_dependencies;}

template <> bool& VectorBranch<bool>::get(size_t) {
    THROW_EXCEPTION("For boolean branches the get() operator is cumbersome");
    return m_default;
}
}
#undef SET_BRANCHSTRING
