/*
  Copyright (C) 2002-2025 CERN for the benefit of the ATLAS collaboration
*/

#ifndef JIVEXML_XAODCALOCLUSTERRetriever_H
#define JIVEXML_XAODCALOCLUSTERRetriever_H

#include <string>
#include <vector>
#include <map>

#include "JiveXML/IDataRetriever.h"
#include "AthenaBaseComps/AthAlgTool.h"
#include "xAODCaloEvent/CaloClusterContainer.h"

class CaloClusterContainer;

namespace JiveXML{

  /**
   * @class xAODCaloClusterRetriever
   * @brief Retrieves all @c Calo Cluster @c objects
   *
   *  - @b Properties
   *    - PriorityClusterCollection: First collection to be retrieved, displayed
   *      in Atlantis without switching. All other collections are
   *      also retrieved.
   *    - OtherClusterCollections
   *    - DoWriteHLT
   *    - DoWriteAllCollections
   *
   *  - @b Retrieved @b Data
   *    - Usual four-vector: phi, eta, et
   *    - No cells in AOD Clusters. numCells is placeholder
   *      for compatibility with 'full' clusters in AtlantisJava
   */
  class xAODCaloClusterRetriever : virtual public IDataRetriever,
				   public AthAlgTool {

  public:

    /// Standard Constructor
    xAODCaloClusterRetriever(const std::string& type,const std::string& name,const IInterface* parent);

    virtual StatusCode retrieve(ToolHandle<IFormatTool> &FormatTool);
    /// Puts the variables into a DataMap
    const DataMap getData(const xAOD::CaloClusterContainer*);
    /// Gets the StoreGate keys for the desired containers 
    const std::vector<std::string> getKeys();
    /// Return the name of the data type that is generated by this retriever
    virtual std::string dataTypeName() const { return m_typeName; };

  private:

    /// The data type that is generated by this retriever
    const std::string m_typeName = "Cluster";

    Gaudi::Property<bool> m_doWriteHLT {this, "DoWriteHLT", false, "Write out other collections that have HLT in the name"};
    Gaudi::Property<bool> m_doWriteAllCollections {this, "DoWriteAllCollections", false, "Write out all CaloCluster collections"};
    Gaudi::Property<std::vector<std::string>> m_otherKeys {this, "OtherClusterCollections", {}, "Other collections to be retrieved. If DoWriteAllCollections is set to true all available CaloCluster collections will be retrieved"};
    Gaudi::Property<std::string> m_priorityKey {this,"PriorityClusterCollection","egammaClusters", "Name of the priority CaloCluster container that will be written out first"};

  };
}
#endif
