/*
  Copyright (C) 2002-2025 CERN for the benefit of the ATLAS collaboration
*/

#ifndef JIVEXML_XAODELECTRONRETRIEVER_H
#define JIVEXML_XAODELECTRONRETRIEVER_H

#include <string>
#include <vector>
#include <map>

#include "JiveXML/IDataRetriever.h"
#include "AthenaBaseComps/AthAlgTool.h"
#include "xAODEgamma/ElectronContainer.h"

namespace JiveXML{

  /**
   * @class xAODElectronRetriever
   * @brief Retrieves all @c Electron @c objects (ElectronAODCollection etc.)
   *
   *  - @b Properties
   *    - PriorityElectronCollection: First collection to be retrieved, displayed
   *      in Atlantis without switching. All other collections are
   *      also retrieved.
   *    - OtherElectronCollections
   *    - DoWriteHLT
   *    - DoWriteAllCollections
   *
   *  - @b Retrieved @b Data
   *    - Usual four-vectors: phi, eta, et etc.
   *    - Associations for clusters and tracks via ElementLink: key/index scheme
   */
  class xAODElectronRetriever : virtual public IDataRetriever,
				public AthAlgTool {

  public:

    /// Standard Constructor
    xAODElectronRetriever(const std::string& type,const std::string& name,const IInterface* parent);

    virtual StatusCode retrieve(ToolHandle<IFormatTool> &FormatTool);
    /// Puts the variables into a DataMap
    const DataMap getData(const xAOD::ElectronContainer*);
    /// Gets the StoreGate keys for the desired containers
    const std::vector<std::string> getKeys();
    /// Return the name of the data type that is generated by this retriever
    virtual std::string dataTypeName() const { return m_typeName; };

  private:
    /// The data type that is generated by this retriever
    const std::string m_typeName = "Electron";

    Gaudi::Property<bool> m_doWriteHLT {this, "DoWriteHLT", false, "Write out other collections that have HLT in the name"};
    Gaudi::Property<bool> m_doWriteAllCollections {this, "DoWriteAllCollections", false, "Write out all Electron collections"};
    Gaudi::Property<std::vector<std::string>> m_otherKeys {this, "OtherElectronCollections", {}, "Other collections to be retrieved. If DoWriteAllCollections is set to true all available Electron collections will be retrieved"};
    Gaudi::Property<std::string> m_priorityKey {this,"PriorityElectronCollection","Electrons", "Name of the priority Electron container that will be written out first"};

  };
}
#endif
