/*
  Copyright (C) 2002-2025 CERN for the benefit of the ATLAS collaboration
*/

#ifndef XAODJIVEXML_xAODMISSINGETRETRIEVER_H
#define XAODJIVEXML_xAODMISSINGETRETRIEVER_H

#include <string>
#include <vector>
#include <map>

#include "JiveXML/IDataRetriever.h"
#include "AthenaBaseComps/AthAlgTool.h"
#include "xAODMissingET/MissingETContainer.h"

namespace JiveXML{

  /**
   * @class xAODMissingETRetriever
   * @brief Retrieves all @c MissingET @c objects (MissingETAODCollection etc.)
   *
   *  - @b Properties
   *    - PriorityMETCollection: First collection to be retrieved, displayed
   *      in Atlantis without switching. All other collections are
   *      also retrieved.
   *    - OtherMETCollections
   *    - DoWriteHLT
   *    - DoWriteAllCollections
   *
   *  - @b Retrieved @b Data
   *    - Usual four-vectors: phi, eta, et etc.
   *    - Associations for clusters and tracks via ElementLink: key/index scheme
   */
  class xAODMissingETRetriever : virtual public IDataRetriever,
				 public AthAlgTool {

  public:

    /// Standard Constructor
    xAODMissingETRetriever(const std::string& type,const std::string& name,const IInterface* parent);

    virtual StatusCode retrieve(ToolHandle<IFormatTool> &FormatTool);
    /// Puts the variables into a DataMap
    const DataMap getData(const xAOD::MissingETContainer*);
    /// Gets the StoreGate keys for the desired containers
    const std::vector<std::string> getKeys();
    /// Return the name of the data type that is generated by this retriever
    virtual std::string dataTypeName() const { return m_typeName; };

  private:

    /// The data type that is generated by this retriever
    const std::string m_typeName = "ETMis";

    Gaudi::Property<bool> m_doWriteHLT {this, "DoWriteHLT", false, "Write out other collections that have HLT in the name"};
    Gaudi::Property<bool> m_doWriteAllCollections {this, "DoWriteAllCollections", false, "Write out all MET collections"};
    Gaudi::Property<std::vector<std::string>> m_otherKeys {this, "OtherMETCollections", {"MET_Reference_AntiKt4EMTopo", "MET_Calo", "MET_LocHadTopo", "MET_Core_AntiKt4LCTopo"}, "Other collections to be retrieved. If DoWriteAllCollections is set to true all available MET collections will be retrieved"};
    Gaudi::Property<std::string> m_priorityKey {this,"PriorityMETCollection","MET_Reference_AntiKt4EMPFlow", "Name of the priority MET container that will be written out first"};

  };
}
#endif // not XAODJIVEXML_xAODMISSINGETRETRIEVER_H
