/*
  Copyright (C) 2002-2024 CERN for the benefit of the ATLAS collaboration
*/

#ifndef JIVEXML_LVL1RESULTRETRIEVER_H
#define JIVEXML_LVL1RESULTRETRIEVER_H

#include <string>

#include "JiveXML/IDataRetriever.h"

#include "AthenaBaseComps/AthAlgTool.h"

#include "TrigDecisionTool/TrigDecisionTool.h"

namespace JiveXML{

  class LVL1ResultRetriever : virtual public IDataRetriever, public AthAlgTool {

  public:

    /// Standard Constructor
    LVL1ResultRetriever(const std::string& type, const std::string& name, const IInterface* parent);

    /// Retrieve all the data
    virtual StatusCode retrieve(ToolHandle<IFormatTool> &FormatTool);

    /// Return the name of the data type
    virtual std::string dataTypeName() const { return m_typeName; };

    //Initialize
    StatusCode initialize(); 

    /// Subroutine for constructing the item list string
    StatusCode getItemLists(const Trig::ChainGroup* chains, 
                            std::string& listName, std::string& prescaleName);

  private:

    ///The data type that is generated by this retriever
    const std::string m_typeName = "LVL1Result";

    /// A handle to the TrigDecisionTool
    PublicToolHandle<Trig::TrigDecisionTool> m_trigDecTool {this, "TrigDecisionTool", "Trig::TrigDecisionTool/TrigDecisionTool", "Tool to access TrigDecision"};

    /// the trigger chains
    const Trig::ChainGroup* m_all = nullptr;
    const Trig::ChainGroup* m_allL1 = nullptr;
    const Trig::ChainGroup* m_allL2 = nullptr;
    const Trig::ChainGroup* m_allEF = nullptr;
    const Trig::ChainGroup* m_allHLT = nullptr;
  };

}
#endif
