# Copyright (C) 2002-2024 CERN for the benefit of the ATLAS collaboration

# Categories currently used by offline Egamma TO monitoringMT tool
# Mechanism to read mongroups directly from trigger menu

from AthenaMonitoring.DQConfigFlags import DQDataType

def mongroupsCfg(moniAccess, data_type):

        shifter_eg = moniAccess.monitoredChains(signatures="egammaMon", monLevels=["shifter"])
        shifter_tp = moniAccess.monitoredChains(signatures="egammaMon", monLevels=["shifter_tp"])
        shifter_topo = moniAccess.monitoredChains(signatures="egammaMon", monLevels=["shifter_topo"])

        monitoring_electron = list(filter(lambda x: ('HLT_e' in x and 'L1eEM28' not in x), shifter_eg)) # etcut chains
        monitoring_tags = []
        monitoringTP_electron = list(filter(lambda x: ('L1eEM28' not in x), shifter_tp))
        
        monitoring_ph = list(filter(lambda x: ('HLT_g' in x and 'ringer' not in x), shifter_eg))
        monitoring_ph_ringer = ['HLT_g20_tight_ringer_L1eEM18M', 'HLT_g25_loose_ringer_L1eEM24L','HLT_g22_tight_ringer_L1eEM18M','HLT_g25_medium_ringer_L1eEM24L','HLT_g35_medium_ringer_L1eEM24L','HLT_g50_loose_ringer_L1eEM24L','HLT_g140_loose_ringer_L1eEM26M']
        monitoring_photon = monitoring_ph + monitoring_ph_ringer + ['HLT_g140_loose_L1eEM26M','HLT_g300_etcut_L1eEM26M']
        monitoring_bootstrap = {
                'HLT_g22_tight_L1eEM18M'  : 'HLT_g20_tight_L1eEM18M',
                'HLT_g25_medium_L1eEM24L' : 'HLT_g25_loose_L1eEM24L',
                'HLT_g35_medium_L1eEM24L' : 'HLT_g25_loose_L1eEM24L',
                'HLT_g50_loose_L1eEM24L'  : 'HLT_g25_loose_L1eEM24L',
                'HLT_g22_tight_ringer_L1eEM18M'  : 'HLT_g20_tight_ringer_L1eEM18M',
                'HLT_g25_medium_ringer_L1eEM24L' : 'HLT_g25_loose_ringer_L1eEM24L',
                'HLT_g35_medium_ringer_L1eEM24L' : 'HLT_g25_loose_ringer_L1eEM24L',
                'HLT_g50_loose_ringer_L1eEM24L'  : 'HLT_g25_loose_ringer_L1eEM24L'
        }

        t0_tp = moniAccess.monitoredChains(signatures="egammaMon", monLevels=["t0_tp"])

        validationTP_electron_DNN = list(filter(lambda x: ('_dnn' in x), t0_tp ))
        validation_electron = ['HLT_e25_etcut_L1eEM18M','HLT_e60_etcut_L1eEM26M']
        validation_jpsi = list(filter(lambda x: ('_L1JPSI' in x), shifter_topo ))
        validationTP_jpsiee = ['HLT_e10_lhvloose_L1eEM9']

        monitoring_topo = []
        mongroups = { 
                'monitoring_electron'           : monitoring_electron,
                'monitoring_photon'             : monitoring_photon ,
                'monitoring_bootstrap'          : monitoring_bootstrap,
                'monitoringTP_electron'         : monitoringTP_electron + ['HLT_e26_lhtight_L1eEM26M'],
                'monitoring_tags'               : monitoring_tags,
                'monitoring_topo'               : monitoring_topo,
        }

        if data_type is DQDataType.MC:
                
                mongroups['validation_electron']        = validation_electron
                mongroups['validation_photon']          = monitoring_photon 
                mongroups['validation_jpsi']            = validation_jpsi
                mongroups['validationTP_jpsiee']        = validationTP_jpsiee
                mongroups['validationTP_electron_DNN']  = validationTP_electron_DNN


        elif data_type is DQDataType.HeavyIon:
                mongroups['monitoring_electron_hi'] = ['HLT_e15_etcut_ion_L1eEM15','HLT_e30_etcut_ion_L1eEM26','HLT_e15_lhloose_nogsf_ion_L1eEM15','HLT_e15_loose_nogsf_ion_L1eEM15']
                mongroups['monitoring_electron_TP_hi'] = ['HLT_e20_lhloose_nogsf_ion_L1eEM18','HLT_e20_loose_nogsf_ion_L1eEM18']
                mongroups['monitoring_photon_hi'] = ['HLT_g15_loose_ion_L1eEM12','HLT_g20_etcut_ion_L1eEM15','HLT_g50_loose_ion_L1eEM26']
                mongroups['monitoring_bootstrap_hi']    = {'HLT_g18_etcut_ion_L1eEM12' : 'HLT_g18_etcut_ion_L1eEM12'}

        elif data_type is DQDataType.Cosmics:
                monitoring_electron_cosmic=['HLT_e5_etcut_L1eEM5']
                monitoring_photon_cosmic=['HLT_g3_etcut_LArPEB_L1eEM5']
                monitoring_bootstrap_cosmic = {'HLT_g3_etcut_LArPEB_L1eEM5' : 'HLT_g3_etcut_LArPEB_L1eEM5'}

                mongroups['monitoring_electron_cosmic']  = monitoring_electron_cosmic
                mongroups['monitoring_photon_cosmic']    = monitoring_photon_cosmic
                mongroups['monitoring_bootstrap_cosmic'] = monitoring_bootstrap_cosmic
        
        return mongroups

# Topolological chains - monitoring configuration
topo_config = {
                    'Zee'   : {'mass':(50 , 130) , 'dphi':(1.5,   5) },
                    'Jpsiee': {'mass':( 1 ,   5) , 'dphi':(1.5,   5) },
                    'Heg'   : {'mass':(90 , 140) , 'dphi':(1.5,   5) },
              }

######  For Offine EGamma DQ purposes: Offline EGamma Trigger aware implementation ######
# Chains retrived in the egammaPerformance/SetupEgammaMonitoring
# Chains inside the ​Physics_pp_run3_v1.py menu:
######  

primary_single_ele = [
        'HLT_e26_lhtight_ivarloose_L1eEM26M',
        'HLT_e26_lhtight_ivarloose_L1eEM26T',
        'HLT_e28_lhtight_ivarloose_L1eEM28M',
        'HLT_e60_lhmedium_L1eEM26M',
        'HLT_e140_lhloose_L1eEM26M']

primary_double_pho = [
        'HLT_2g22_tight_L12eEM18M',
        'HLT_g35_medium_g25_medium_L12eEM24L',
        'HLT_2g50_loose_L12eEM24L',
        ]

monitoring_Zee = ['HLT_e26_lhtight_e14_etcut_probe_50invmAB130_L1eEM26M',
                'HLT_e26_lhtight_e14_etcut_L1eEM26M',
                'HLT_e26_lhtight_e14_etcut_probe_50invmAB130_L1eEM26M',
                'HLT_e26_lhtight_e14_etcut_L1eEM26M'
                ] + primary_single_ele

monitoring_Jpsiee = [
        'HLT_e5_lhtight_e9_etcut_1invmAB5_L1JPSI-1M5-eEM9',
        'HLT_e5_lhtight_e14_etcut_1invmAB5_L1JPSI-1M5-eEM15',
        'HLT_e9_lhtight_e4_etcut_1invmAB5_L1JPSI-1M5-eEM9',
        'HLT_e14_lhtight_e4_etcut_1invmAB5_L1JPSI-1M5-eEM15',
        'HLT_e10_lhvloose_L1eEM9',
        'HLT_e14_lhvloose_L1eEM12L'
        ]
