#
#  Copyright (C) 2002-2024 CERN for the benefit of the ATLAS collaboration
#
from AthenaMonitoringKernel.GenericMonitoringTool import GenericMonitoringTool
import math


def CTPUnpackingMonitoring(flags, maxItems, maxChains):
    tool = GenericMonitoringTool(flags, 'MonTool')
    tool.HistPath="HLTFramework/HLTSeeding"
    tool.defineHistogram('TAVItems', path='EXPERT', type='TH1F', title='Number of active L1 TAV items;N Items;N Events',
                         xbins=maxItems, xmin=0, xmax=maxItems)
    tool.defineHistogram('Chains', path='EXPERT', type='TH1F', title='Number of activated Chains;N Chains;N Events',
                         xbins=(maxChains//4 if maxChains>100 else maxChains), xmin=0, xmax=maxChains)
    return tool


def RoIsUnpackingMonitoring(flags, prefix, maxCount, maxEta=3., phiOffset=0.,etaOffset=0.):
    tool = GenericMonitoringTool(flags, 'MonTool')
    tool.HistPath = f'HLTFramework/HLTSeeding/RoIs_{prefix}'
    tool.defineHistogram('count', path='EXPERT', type='TH1F', title=f'Number of {prefix} RoIs;N RoIs;N Events',
                         xbins=maxCount, xmin=0, xmax=maxCount)
    tool.defineHistogram('eta', path='EXPERT', type='TH1F', title=f'{prefix} RoIs eta;eta;N RoIs',
                         xbins=int(20*maxEta), xmin=-(maxEta-etaOffset), xmax=(maxEta+etaOffset))
    tool.defineHistogram('phi', path='EXPERT', type='TH1F', title=f'{prefix} RoIs phi;phi;N RoIs',
                         xbins=64, xmin=-(math.pi-phiOffset), xmax=(math.pi+phiOffset))
    tool.defineHistogram('eta,phi', path='EXPERT', type='TH2F', title=f'{prefix} RoIs eta-phi;eta;phi;N RoIs',
                         xbins=int(20*maxEta), xmin=-(maxEta-etaOffset), xmax=(maxEta+etaOffset),
                         ybins=64, ymin=-(math.pi-phiOffset), ymax=(math.pi+phiOffset))
    
    return tool


def PrescalingMonitoring(flags):
    tool = GenericMonitoringTool(flags, 'MonTool')
    tool.HistPath="HLTFramework/HLTSeeding"
    tool.defineHistogram('LB,HLTPSK', path='EXPERT', type='TH2I', opt='kAddBinsDynamically',
                         title='HLT prescale key used in LB;Lumiblock;HLTPSK',
                         xbins=100, xmin=0, xmax=100, ybins=5, ymin=0, ymax=5)
    tool.defineHistogram('Random', path='EXPERT', type='TH1F',
                         title='Random number distribution;random number',
                         xbins=100, xmin=0, xmax=1)
    return tool


def L1DataConsistencyMonitoring(flags):
    tool = GenericMonitoringTool(flags, 'MonTool')
    tool.HistPath="HLTFramework/HLTSeeding/L1DataConsistencyChecker"

    tool.defineHistogram('TIME_consistencyCheck', path='EXPERT', type='TH1F',
                         title='Time of consistencyCheck() calls;Time [ms];N calls',
                         xbins=100, xmin=0, xmax=50)
    tool.defineHistogram('MissingTOBs', path='EXPERT', type='TH1F',
                         title='L1 thresholds with missing TOBs;Threshold name;Events with missing TOBs',
                         xbins=10, xmin=0, xmax=10)
    tool.defineHistogram('MissingTOBsIncludingOverflow', path='EXPERT', type='TH1F',
                         title='L1 thresholds with missing TOBs (incl. overflow);Threshold name;Events with missing TOBs',
                         xbins=10, xmin=0, xmax=10)
    tool.defineHistogram('ThrName,CtpCount', path='EXPERT', type='TH2F',
                         title='Max threshold multiplicity accepted by CTP;Threshold name;Multiplicity',
                         xbins=50, xmin=0, xmax=50, ybins=20, ymin=0, ymax=20)
    tool.defineHistogram('ThrName,TobCount', path='EXPERT', type='TH2F',
                         title='Number of TOBs passing thresholds;Threshold name;Number of TOBs',
                         xbins=50, xmin=0, xmax=50, ybins=200, ymin=0, ymax=200)
    tool.defineHistogram('ThrName,TobMinusCtpCount', path='EXPERT', type='TH2F',
                         title='Diff. between N TOBs and CTP multiplicity;Threshold name;N TOBs - CTP multiplicity',
                         xbins=50, xmin=0, xmax=50, ybins=250, ymin=-50, ymax=200)
    return tool
